==> freebsd-lib-8.2.tar.bz2: lib/libedit/prompt.h <==
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Christos Zoulas of Cornell University.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)prompt.h	8.1 (Berkeley) 6/4/93
 *	$NetBSD: prompt.h,v 1.6 2003/08/07 16:44:32 agc Exp $
 * $FreeBSD: src/lib/libedit/prompt.h,v 1.3.10.1.6.1 2010/12/21 17:09:25 kensmith Exp $
 */

/*
 * el.prompt.h: Prompt printing stuff
 */
#ifndef _h_el_prompt
#define	_h_el_prompt

#include "histedit.h"

typedef char * (*el_pfunc_t)(EditLine*);

typedef struct el_prompt_t {
	el_pfunc_t	p_func;	/* Function to return the prompt	*/
	coord_t		p_pos;	/* position in the line after prompt	*/
} el_prompt_t;

protected void	prompt_print(EditLine *, int);
protected int	prompt_set(EditLine *, el_pfunc_t, int);
protected int	prompt_get(EditLine *, el_pfunc_t *, int);
protected int	prompt_init(EditLine *);
protected void	prompt_end(EditLine *);

#endif /* _h_el_prompt */

==> freebsd-lib-9.2_rc2.tar.bz2: lib/libedit/prompt.h <==
/*-
 * Copyright (c) 1992, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Christos Zoulas of Cornell University.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 *	@(#)prompt.h	8.1 (Berkeley) 6/4/93
 *	$NetBSD: prompt.h,v 1.6 2003/08/07 16:44:32 agc Exp $
 * $FreeBSD: releng/9.2/lib/libedit/prompt.h 237738 2012-06-29 03:01:38Z pfg $
 */

/*
 * el.prompt.h: Prompt printing stuff
 */
#ifndef _h_el_prompt
#define	_h_el_prompt

#include "histedit.h"

typedef char * (*el_pfunc_t)(EditLine*);

typedef struct el_prompt_t {
	el_pfunc_t	p_func;	/* Function to return the prompt	*/
	coord_t		p_pos;	/* position in the line after prompt	*/
	char		p_ignore;	/* character to start/end literal 
*/
} el_prompt_t;

protected void	prompt_print(EditLine *, int);
protected int	prompt_set(EditLine *, el_pfunc_t, char, int);
protected int	prompt_get(EditLine *, el_pfunc_t *, char *, int);
protected int	prompt_init(EditLine *);
protected void	prompt_end(EditLine *);

#endif /* _h_el_prompt */
